@@ -1,5 +1,5 @@
 package Tangerine::hook::tests;
-$Tangerine::hook::tests::VERSION = '0.22';
+$Tangerine::hook::tests::VERSION = '0.23';
 use 5.010;
 use strict;
 use warnings;
@@ -18,7 +18,7 @@ sub run {
                 Tangerine::hook::testloading->new(type => 'runtime') ] );
     }
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 1 &&
-        $s->[1] eq 'Test::Requires') {
+        (any { $s->[1] eq $_ } qw(Test::Needs Test::Requires))) {
         require Tangerine::hook::testrequires;
         return Tangerine::HookData->new( hooks => [
                 Tangerine::hook::testrequires->new(type => 'runtime') ] );
